<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Um cliente Jabber/XMPP simples e fácil de usar</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Licença:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Veja código-fonte online</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Relatar problemas</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Segurança da Conta</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation>Permitir adicionar novos dispositivos usando um Código-QR, mas nunca mostrar a senha como texto. Esta ação não poderá ser desfeita, porém, considere armazenar a senha de outra forma antes de usá-la.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation>Desativar visibilidade da senha</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation>Não mostra a senha de nenhuma forma. Esta ação não pode ser desfeita.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation>Desativar a exibição do código QR e da senha</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Transferência da conta para outro dispositivo</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Escaneie o código QR ou digite as credenciais como texto em outro dispositivo para entrar nele.

Atenção:
Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à sua conta!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Endereço do bate-papo:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Ocultar código QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Mostrar como código QR</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Ocultar texto</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Mostrar como texto</translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation>Copiar JID</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Copiar senha</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Alterar a senha</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Senha atual:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nova senha:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Nova senha (digite de novo):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>As senhas não são iguais.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>A senha atual é inválida.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Você precisa estar online para mudar sua senha.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Depois de mudar sua senha, você precisará digitá-la novamente em todos os seus outros dispositivos.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Alterar</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation>Senha alterada com sucesso</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Falhou ao alterar a senha: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixar</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Copiar mensagem</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Editar mensagem</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Copiar URL de download</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Citar mensagem</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Escrever mensagem</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Enviar uma mensagem de spoiler</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Dica de spoiler</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Ativar notificações</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Silenciar notificações</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Veja perfil</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fechar</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Pesquisar para cima</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Pesquisar em baixo</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Todos os arquivos</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation>Fechar barra de pesquisa de mensagens</translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation>Dica de spoiler</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation>Fechar campo de dica de spoiler</translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation>Escrever mensagem</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>Não foi possível excluir sua conta do servidor. Por essa razão, ela também não foi excluída deste aplicativo: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Muito baixa</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Muito alta</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Qualidade constante</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Taxa de bits constante</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Taxa de bits média</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Passo duplo</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation>Configurações de conexão</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Alterar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation>Não foi possível alterar as configurações de conexão</translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation>Configurações de conexão alteradas</translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation>O nome do servidor não pode conter espaços em branco</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation>Excluir senha por completo</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>A sua senha não será mais incluída no código QR.
Você não poderá usar o login via código QR sem inserir sua senha novamente porque esta ação não pode ser desfeita!
Certifique-se de que fez o backup se quiser usar sua conta mais tarde.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation>Excluir senha</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation>Não mostre senha como texto</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>A partir de agora sua senha não será mais exibida como texto.
Você não será capaz de ver sua senha como texto novamente, porque essa ação não pode ser desfeita!
Certifique-se de fazer o backup dela se você deseja usar a sua conta mais tarde.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation>Não mostre a senha</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Não foi possível salvar arquivo: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Download falhou: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Favoritos</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Pessoas</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Natureza</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Alimentos</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Atividade</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Viagens</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Objetos</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Símbolos</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Bandeiras</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Procura</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Procura emoji</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Por favor, selecione um bate-papo para iniciar conversa</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Convide amigos</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Link do convite copiado para a área de transferência</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Online</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Trocar dispositivo</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>O link será aberto depois que você tiver conectado.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Não foi possível encontrar um código QR válido.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Excluir conta deste aplicativo</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>A sua conta será excluida deste app.
Sua senha também será excluída, certifique-se de que ela é armazenada num gerenciador de senhas ou você memorizou ela!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Faça login na sua conta XMPP</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation>Configurações de conexão</translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation>Configurações de conexão</translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation>As configurações da conexão serão salvas de forma permanente após a primeira autenticação. Se não funcionar, retorne para a página de login.</translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation>Ativar configurações de conexão avançadas</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Predefinido</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Tirar uma foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Gravar vídeo</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Gravar voz</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Enviar localização</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Escolha arquivo</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Escolha imagem</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Escolha vídeo</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Escolher arquivo de áudio</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Escolher documento</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Arquivos de áudio</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Documento</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Local</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Message could not be sent.</source>
        <translation>Não foi possível enviar a mensagem.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Não foi possível a correção da mensagem.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>Aguardando</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Entregue</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Configurações de multimídia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configure</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Captura da Imagem</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Gravação de Áudio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Gravação de Vídeo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Entrada de áudio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Container</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Taxa de Amostra</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Taxa de Quadros</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Iniciando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Gravando…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="vanished">Pronto</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Iniciando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Gravando… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>Pausado %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Excluir senha</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>Você pode decidir a não divulgar sua senha para &lt;b&gt;%1&lt;/b&gt; como texto ou removê-lo completamente de transferência da conta. Se você remover a senha completamente, você não será capaz de usar transferência da conta escaneando, sem digitar a senha, porque ela também será removida do código QR.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Não mostrar senha como texto</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Remover completamente</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Marcar como lido</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Livre para bate-papo</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Ausente</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Não perturbe</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Ausente por mais tempo</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="vanished">Disponível</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Livre para bate-papo</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Indisponível</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Não perturbe</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Indisponível por mais tempo</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Offline</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Erro</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Nome de usuário ou senha inválido.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Não é possível conectar ao servidor. Por favor, verifique sua conexão de internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>O servidor não suporta conexões seguras.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Erro ao tentar conectar-se de modo seguro.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="vanished">Não foi possível resolver o endereço do servidor. Verifique o nome do seu servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>O protocolo de autenticação não é compatível com o servidor.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Este servidor não suporta registração.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>O servidor está offline ou bloqueado por um firewall.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>A conexão não pôde ser atualizada.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>O acesso à Internet não é permitido. Por favor, verifique a configuração de acesso à Internet do seu sistema.</translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation>Não foi possível conectar com o servidor. Verifique sua conexão com a internet ou o nome do seu servidor.</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Geração do código QR falhou: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Escanear código QR</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Mostrar explicação</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Continue sem código QR</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Escaneie o código QR do dispositivo existente para transferir sua conta.</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>O formato da câmera &apos;%1&apos; não é compatível.</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Não há câmera disponível.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>Sua câmera está em uso.
Tente fechar outros aplicativos que estão usando a câmera.</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">Escanear código QR</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="vanished">Não há câmera disponível.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="vanished">Sua câmera está em uso.
Tente fechar outros aplicativos que estão usando a câmera.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="vanished">O formato da câmera &apos;%1&apos; não é compatível.</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="vanished">Escaneie o código QR do dispositivo existente para transferir sua conta.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="vanished">Mostrar explicação</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="vanished">Escaneie</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="vanished">Continue sem código QR</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="vanished">Conectando…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Registrar nova conta</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Utilizar uma conta existente</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Senha alterada com êxito.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Falhou ao alterar a senha: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Excluir a conta por completo</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>Sua conta será excluída por completo, ou seja, deste aplicativo e do servidor.
Você não poderá usar sua conta novamente!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Adicionar novo contato</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Isso também enviará uma solicitação de acesso à disponibilidade do contato.</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>ID do Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>usuário@exemplo.org</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Apelido:</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Mensagem opcional:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Informe o seu parceiro de bate-papo quem você é.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicione</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Erro: Verifique o JID.</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Não foi possível adicionar contato, devido a não estar conectado à Internet.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Não foi possível excluir contato, devido a não estar conectado à Internet.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Spoiler</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Não foi possível alterar o nome de contato, devido a não estar conectado à Internet.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Contatos</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Adicionar novo contato</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Procurar contatos</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Você realmente deseja excluir o contato &lt;b&gt;%1&lt;/b&gt; da sua lista?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Excluir contato</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation>Deseja realmente excluir o contato &lt;b&gt;%1&lt;/b&gt; da sua lista de contatos?</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Alterar nome do contato</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Alterar o nome</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation>Legenda</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Servidor personalizado</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Nenhuma limitação</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 dias</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Alterar senha</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Altera a senha da sua conta. Será necessário digitá-la novamente nos seus outros dispositivos.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Configurações de Multimídia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Definir as configurações de foto, vídeo e gravação de áudio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Segurança da conta</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation type="vanished">define se este dispositivo pode ser usado para fazer login num outro dispositivo</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Excluir conta de Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Excluir conta deste aplicativo</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Excluir conta</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Excluir conta do servidor</translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation>Configurações de conexão</translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation>Configure o servidor e a porta para conexão</translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on a new device</source>
        <translation>Configurar se este dispositivo pode ser usado para fazer o login em um novo dispositivo</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Aproveite a comunicação gratuita em cada aparelho!</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>Vamos começar</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Pedido de Inscrição</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Você recebeu um pedido de inscrição de &lt;b&gt;%1&lt;/b&gt;. Se você aceitá-lo, o usuário terá acesso ao seu status de disponibilidade.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Rejeitar</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Aceitar</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Não foi possível enviar o arquivo, devido a não estar conectado à Internet.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Arquivo</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Não foi possível enviar a mensagem.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Perfil</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Renomear contato</translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation>Mostrar código QR</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Remover contato</translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation>Dispositivos online</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apelido</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Aniversário</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Site da web</translation>
    </message>
</context>
</TS>
